package App::expandtab ;  
our $VERSION = '0.020' ; 
our $DATE = '2021-06-12T22:27+09:00' ; 

=encoding utf8

=head1 NAME

App::expandtab

=head1 SYNOPSIS

This module provides a Unix-like command `F<expandtab>'. 


Text::VisualWidth を利用して、全角文字が混ざっていても、さらにはASCIIカラーコード付きの文字が混ざっていても、TSV形式(タブ区切り)のテキストデータに対して、各列が同じ位置に揃うように出力する。


=head1 DESCRIPTION



=head1 SEE ALSO


=cut

1 ;
